# Accessibility

All components should be accessible!

## Testing

Code is automatically checked with [eslint-plugin-jsx-a11y](https://github.com/jsx-eslint/eslint-plugin-jsx-a11y).  
All components should be tested with [jest-axe](https://github.com/nickcolley/jest-axe) for accessibility issues.  
**Note** This only catches a small amount of issues and manual testing is still required by both designers & developers.

## Elements

### `<abbr>`

The [abbreviation element is not accessible by itself](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/abbr#accessibility_concerns). It can be hard to understand without correct text content and can't be accessed by keyboard.

1. Spell out the acronym or abbreviation in full the first time it is used on a page.
2. Make sure to use accessible markup. Tabindex makes is accessible by keyboard and class name will display the content.

```html
<abbr class="sds-typography-abbr" tabindex="0" title="Sikt Design System">
  SDS
</abbr>
```

### `<input type="date">`

_TODO_

### Maps

_TODO_

## Stylesheets

### CSS content

If CSS content property carry meaning it need an accessible alternative [since it is not accessible by itself](https://developer.mozilla.org/en-US/docs/Web/CSS/content#accessibility_concerns). CSS alternatives are not fully supported yet, see [CSS property: content: Alternative text](https://caniuse.com/mdn-css_properties_content_alt_text) or [CSS property: alt](https://caniuse.com/mdn-css_properties_alt). So for the time being valid options are using `aria-label` or a `.sds-screen-reader-only` element containing the additional information.
